@@ -24,13 +24,13 @@ from sqlalchemy_utils import (
     PhoneNumberType,
     UUIDType,
 )
-from sqlalchemy_utils.types import arrow, phone_number
-from wtforms_components import (
+from sqlalchemy_utils.types import arrow, phone_number, WeekDaysType
+from wtforms_components import Email
+from wtforms_components.fields import (
     ColorField,
     DateField,
     DateTimeField,
     DecimalField,
-    Email,
     EmailField,
     IntegerField,
     IntIntervalField,
@@ -40,6 +40,7 @@ from wtforms_components import (
     StringField,
     TimeField,
 )
+from wtforms_components.fields.weekdays import WeekDaysField
 from wtforms_alchemy import (
     ModelForm,
     SelectField,
@@ -232,6 +233,22 @@ class TestModelColumnToFormFieldTypeConversion(ModelFormTestCase):
         self.assert_type('test_column', SelectField)
         assert self.form_class().test_column.choices == choices
 
+    def test_choice_type_uses_custom_coerce_func(self):
+        choices = [(u'1', u'choice 1'), (u'2', u'choice 2')]
+        self.init(type_=ChoiceType(choices))
+        self.assert_type('test_column', SelectField)
+        model = self.ModelTest(test_column=u'2')
+        form = self.form_class(obj=model)
+        assert '<option selected value="2">' in str(form.test_column)
+
+
+class TestWeekDaysTypeConversion(ModelFormTestCase):
+    dns = 'postgres://postgres@localhost/wtforms_alchemy_test'
+
+    def test_weekdays_type_converts_to_weekdays_field(self):
+        self.init(type_=WeekDaysType)
+        self.assert_type('test_column', WeekDaysField)
+
 
 class TestCustomTypeMap(ModelFormTestCase):
     def test_override_type_map_on_class_level(self):
