@@ -35,6 +35,7 @@ from wtforms_components import (
     SelectField,
     StringField,
     TimeField,
+    WeekDaysField,
 )
 from wtforms_components.widgets import (
     ColorInput,
@@ -52,6 +53,7 @@ from .exc import (
     UnknownTypeException
 )
 from .utils import (
+    choice_type_coerce_factory,
     flatten,
     is_date_column,
     is_number,
@@ -100,6 +102,7 @@ class FormGenerator(object):
         (types.PhoneNumberType, PhoneNumberField),
         (types.ScalarListType, StringField),
         (types.UUIDType, StringField),
+        (types.WeekDaysType, WeekDaysField),
     ))
 
     WIDGET_MAP = OrderedDict((
@@ -449,6 +452,8 @@ class FormGenerator(object):
 
         :param column: SQLAlchemy Column object
         """
+        if isinstance(column.type, types.ChoiceType):
+            return choice_type_coerce_factory(column.type)
         try:
             python_type = column.type.python_type
         except NotImplementedError:
